@@ -1,4 +1,5 @@
 import colorsys
+import random
 from PIL.ImageColor import getrgb
 from email.MIMEMultipart import MIMEMultipart
 from email.MIMEText import MIMEText
@@ -43,6 +44,21 @@ def getSecret():
 
 
 
+def randomString(length=16):
+    """Return 32 bytes of random data. Only characters which do not require
+    special escaping in HTML or URLs are generated."""
+
+    safe_characters = "abcdefghijklmnopqrstuvwxyz" \
+                      "ABCDEFGHIJKLMNOPQRSTUVWXYZ" \
+                      "1234567890-"
+    output = []
+    append = output.append
+    for i in xrange(length):
+        append(random.choice(safe_characters))
+    return "".join(output)
+
+
+
 def jsonify(func, *args, **kwargs):
     request=getattr(args[0], "request")
     request.response.setHeader("Content-Type", "application/json")
@@ -198,6 +214,21 @@ class WebHelpers(BrowserView):
         return sector.absolute_url()
 
 
+    @reify
+    def _survey(self):
+        from euphorie.client.session import SessionManager
+        survey=getattr(self.request, "survey", None)
+        if survey is not None:
+            return survey
+
+        session=SessionManager.session
+        if session is None:
+            return None
+
+        return self.request.client.restrictedTraverse(session.zodb_path.split("/"))
+        
+
+
     @memoize
     def survey_url(self, phase=None):
         """Return the URL for the curreny survey.
@@ -205,7 +236,7 @@ class WebHelpers(BrowserView):
         If a phase is specified the URL for the first page of that
         phase is returned.
         """
-        survey=getattr(self.request, "survey", None)
+        survey=self._survey
         if survey is None:
             return None
         url=survey.absolute_url()
@@ -214,6 +245,12 @@ class WebHelpers(BrowserView):
         return url
 
 
+    @reify
+    def in_session(self):
+        """Check if there is an active survey session."""
+        return self._survey is not None
+
+
     @reify
     def appendix(self):
         """Return a list of items to be shown in the appendix."""
